import 'package:firebase/models/folder_model_firebase.dart';
import 'package:flutter/material.dart';

import 'info_dialog.dart';
import 'models/friend_model.dart';
import 'models/friend_model_firebase.dart';

class AddFriend extends StatelessWidget {

  final TextEditingController _codeController = TextEditingController();
  final TextEditingController _nameController = TextEditingController();
  final String userCredential;

  AddFriend(this.userCredential, {Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text("Add contact")
      ),
      body: Column(
        mainAxisSize: MainAxisSize.max,
        children: [
          const SizedBox(height: 15.0),
          _buildTextField(_codeController, "Code"),
          _buildTextField(_nameController, "Name"),
          Padding(
            padding: const EdgeInsets.all(10.0),
            child: _buildTextButton(context),
          ),
        ],
      )
    );
  }

  Widget _buildTextField(TextEditingController controller, String label) {
    return Padding(
      padding: const EdgeInsets.all(5.0),
      child: TextField(
        controller: controller,
        decoration: InputDecoration(
          label: Text(label),
          border: const OutlineInputBorder(),
        ),
      ),
    );
  }

  TextButton _buildTextButton(BuildContext context) {
    return TextButton(
      child: const Text(
        "Submit",
        style: TextStyle(
          fontSize: 18.0,
          color: Colors.white,
        ),
      ),
      onPressed: () async {
        bool correctCode = await FolderModelFirebase.userExists(_codeController.text);
        await _showResultDialog(context, correctCode);
        if(correctCode) _addFriend(context);
      },
      style: ButtonStyle(
        backgroundColor: MaterialStateProperty.all(Colors.blueAccent),
      ),
    );
  }

  Future<void> _showResultDialog(BuildContext context, bool wasSuccess) async {
    final message = wasSuccess ? "Contact added successfully."
        : "Incorrect code or Contact does not have any collections, try again.";
    await showDialog<String>(
      context: context,
      builder: (BuildContext context) {
        return InfoDialog(dialogContent: message, optionContent: "OK",);
      },
    );
  }

  void _addFriend(BuildContext context) async {
    FriendModel friend;
    friend = FriendModel.id(userCredential, _codeController.text, _nameController.text);
    FriendModelFirebase.storeFriend(friend);
    Navigator.of(context).pop();
  }
}
