import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:firebase/models/friend_model_firebase.dart';
import 'package:flutter/material.dart';

import 'firebase/firebase_handler.dart';
import 'grid_view_list.dart';
import 'intro_page.dart';
import 'models/friend_model.dart';

class FriendsList extends StatelessWidget {

  final FirebaseHandler _firebaseHandler = FirebaseHandler();
  final String userCredential;

  FriendsList(this.userCredential, {Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text("My contacts"),
      ),
      body: _buildListView(),
    );
  }

  Widget _buildListView() {
    final _stream = _firebaseHandler
          .getFirebaseCollectionByNameOwningId('friends',userCredential);

    return StreamBuilder<QuerySnapshot>(
      stream: _stream,
      builder: (BuildContext context, AsyncSnapshot<QuerySnapshot> snapshot) {

        if (snapshot.hasError) {
          return _buildCenteredText('Something went wrong');
        }

        if (snapshot.connectionState == ConnectionState.waiting) {
          return _buildCenteredText('Loading');
        }

        return Padding(
          padding: const EdgeInsets.all(5.0),
          child: ListView(
            children: snapshot.data!.docs
                .map((DocumentSnapshot document) =>
                _createItem(document, context))
                .toList(),
          ),
        );
      },
    );
  }

  Widget _createItem(DocumentSnapshot<Object?> document, BuildContext context) {
    final item = FriendModel.fromJson(document.data()! as Map<String, dynamic>);

    return Padding(
      padding: const EdgeInsets.all(8.0),
      child: ListTile(
        title: Text(item.name),
        onTap: () {
          Navigator.of(context).push(
            MaterialPageRoute(
              builder: (_) => GridViewList(
                title: item.name + '\'s collections',
                firebaseCollectionName: 'folders',
                userCredential: item.friendId,
                onClickAdd: IntroPage.onClickAdd,
                isEditable: false,
              ),
            ),
          );
        },
        trailing: IconButton(
          icon: const Icon(Icons.delete),
          onPressed: () => FriendModelFirebase.deleteItem(item),
        ),
        shape: RoundedRectangleBorder(
          side: const BorderSide(color: Colors.black, width: 1),
          borderRadius: BorderRadius.circular(5)
        ),
        tileColor: Colors.white60,
      ),
    );
  }

  Widget _buildCenteredText(String text) {
    return Center(
      child: Text(text),
    );
  }
}
