import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

import 'add_friend.dart';
import 'friends_list.dart';
import 'info_dialog.dart';

class FriendsPage extends StatelessWidget {

  final String userCredential;
  const FriendsPage(this.userCredential, {Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text("Social"),
      ),
      body: Center(
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.center,
          mainAxisAlignment: MainAxisAlignment.center,
          mainAxisSize: MainAxisSize.max,
          children: [
            _sizedBox(
              () => {
                Navigator.of(context).push(
                  MaterialPageRoute(
                    builder: (_) => FriendsList(userCredential)),
                ),
              },
              "My contacts",
            ),
            _sizedBox(
              () => _showInfoDialog(context, 'Your code is: ' + userCredential),
              "Show my code"),
            _sizedBox(
              () => {
                Clipboard.setData(ClipboardData(text: userCredential)),
                _showInfoDialog(context, 'Code was copied'),
              },
              "Copy my code"
            ),
            _sizedBox(
              () => {
                Navigator.of(context).push(
                  MaterialPageRoute(
                    builder: (_) => AddFriend(userCredential),
                  ),
                ),
              },
              "Add contact by code"
            ),
          ],
        ),
      ),
    );
  }

  Widget _sizedBox(VoidCallback callback, String text) {
    return SizedBox(
      width: 190,
      child: TextButton(
        onPressed: callback,
        child: Text(
          text,
          style: const TextStyle(
            fontSize: 18.0,
            color: Colors.white,
          ),
        ),
        style: ButtonStyle(
          backgroundColor: MaterialStateProperty.all(Colors.blueAccent),
        ),
      ),
    );
  }

  void _showInfoDialog(BuildContext context, String info) async {
    await showDialog<String>(
      context: context,
      builder: (BuildContext context) {
        return InfoDialog(
          dialogContent: info,
          optionContent: 'Got it',
        );
      },
    );
  }
}
