import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:flutter/material.dart';

import 'card_details.dart';
import 'models/folder_model.dart';
import 'models/item_model.dart';

class GridCard extends StatelessWidget {

  final FolderModel? _folder;
  final String _userCredential;
  final bool _isEditable;
  final DocumentSnapshot<Object?> _document;

  const GridCard({Key? key,
    required FolderModel? folder,
    required String userCredential,
    required bool isEditable,
    required DocumentSnapshot<Object?> document}) :
      _folder = folder,
      _userCredential = userCredential,
      _isEditable = isEditable,
      _document = document,
      super(key: key);

  @override
  Widget build(BuildContext context) {
    final card;
    if (_folder == null) {
      card = FolderModel.fromJson(_document.data()! as Map<String, dynamic>);
    } else {
      card = ItemModel.fromJson(_document.data()! as Map<String, dynamic>);
    }

    return Padding(
      padding: EdgeInsets.all(2.0),
      child: Card(
        child: InkWell(
          onTap: () {
            card.onClickCard(card, _userCredential, context, _isEditable);
          },
          child: Column(
            children: _buildMoreActions(context, card),
          ),
        ),
      ),
    );
  }

  List<Widget> _buildMoreActions(BuildContext context, final card) {
    final result = [
      SizedBox(
        height: 65,
        child: ListTile(
          title: Text(card.name, maxLines: 2, overflow: TextOverflow.ellipsis, ),
          subtitle: Text(card.note, maxLines: 1, overflow: TextOverflow.ellipsis, ),
          trailing: const Icon(Icons.arrow_forward_ios),
        ),
      ),
      Expanded(
        child: Padding(
          padding: const EdgeInsets.fromLTRB(5, 0, 5, 0),
          child: Image.network(
            card.imageUrl,
            fit: BoxFit.contain,
          ),
        ),
      ),
    ];
    if (_isEditable) {
      result.add(
        Align(
          alignment: Alignment.centerRight,
          child: InkWell(
            child: const Padding(
              padding: EdgeInsets.fromLTRB(0, 0, 8, 8),
              child: SizedBox(
                child : Icon(Icons.more_horiz),
                height: 20.0,
                width: 30.0,
              ),
            ),
            onTap: () => _askEditOrDeleteDialog(context, card),
          ),
        ),
      );
    } else {
      result.add(const SizedBox(height: 5.0),);
    }
    return result;
  }

  void _askEditOrDeleteDialog(BuildContext context, final card) async {
    await showDialog<String>(
      context: context,
      builder: (BuildContext context) {
        return SimpleDialog(
          title: const Text('Select operation'),
          children: <Widget>[
            SimpleDialogOption(
              onPressed: () => _onPressedEdit(context, card),
              child: const Text('Edit'),
            ),
            SimpleDialogOption(
              onPressed: () => _onPressedDelete(context, card),
              child: const Text('Delete'),
            ),
          ],
        );
      },
    );
  }

  void _onPressedEdit(BuildContext context, final card) {
    Navigator.pop(context);
    Navigator.of(context).push(
      MaterialPageRoute(
        builder: (_) {
          String cardName = "Item";
          if (_folder == null) {
            cardName = "Folder";
          }
          return CardDetails(
            userCredential: _userCredential,
            cardName: cardName,
            editingId: card.id,
            nameController: card.name,
            noteController: card.note,
            existingImageUrl: card.imageUrl,
            folderModel: _folder,
          );
        },
      ),
    );
  }

  void _onPressedDelete(BuildContext context, final card) async {
    Navigator.pop(context);
    showDialog<String>(
      context: context,
      builder: (BuildContext context) {
        return AlertDialog(
          title: Text(card.name, maxLines: 2, overflow: TextOverflow.ellipsis,),
          content: const Text('Are you sure to delete?'),
          actions: [
            TextButton(
              onPressed: () {
                card.onClickDelete();
                Navigator.of(context).pop();
              },
              child: const Text('Yes')),
            TextButton(
              onPressed: () {
                Navigator.of(context).pop();
              },
              child: const Text('No'),
            )
          ],
        );
      },
    );
  }
}
