import 'package:firebase_auth/firebase_auth.dart';
import 'package:flutter/material.dart';
import 'package:google_sign_in/google_sign_in.dart';

import 'card_details.dart';
import 'firebase/firebase_handler.dart';
import 'grid_view_list.dart';
import 'models/folder_model.dart';

class IntroPage extends StatelessWidget {

  final FirebaseHandler _firebaseHandler = FirebaseHandler();

  IntroPage({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Center(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            const Padding(
              padding: EdgeInsets.fromLTRB(0, 0, 0, 20),
              child: Text(
                "Collector's app",
                style: TextStyle(color: Colors.black, fontSize: 30),
              ),
            ),
            TextButton(
              onPressed: () async {
                final userCredential = await _signInWithGoogle(context);
                Navigator.of(context).push(
                  MaterialPageRoute(
                    builder: (_) => GridViewList(
                      title: 'My collections',
                      firebaseCollectionName: 'folders',
                      userCredential: userCredential.user!.uid,
                      onClickAdd: onClickAdd,
                      isEditable: true,
                    ),
                  ),
                );
              },
              child: const Text(
                'Sign in with google',
                style: TextStyle(color: Colors.white, fontSize: 18),
              ),
              style: ButtonStyle(
                backgroundColor: MaterialStateProperty.all(Colors.blueAccent),
              ),
            ),
          ],
        ),
      ),
    );
  }

  static void onClickAdd(
    BuildContext context, FolderModel? folderModel, String userCredential) {
    Navigator.of(context).push(
      MaterialPageRoute(
        builder: (_) {
          return CardDetails(
            userCredential: userCredential,
            cardName: 'Folder',
          );
        },
      ),
    );
  }

  Future<UserCredential> _signInWithGoogle(BuildContext context) async {
    final GoogleSignInAccount? googleUser = await GoogleSignIn().signIn();
    final GoogleSignInAuthentication? googleAuth =
        await googleUser?.authentication;

    final credential = GoogleAuthProvider.credential(
      accessToken: googleAuth?.accessToken,
      idToken: googleAuth?.idToken,
    );
    return await _firebaseHandler.signIn(credential);
  }
}
