import 'package:flutter/material.dart';
import 'package:json_annotation/json_annotation.dart';
import 'package:uuid/uuid.dart';

import '../card_details.dart';
import '../grid_view_list.dart';
import 'folder_model_firebase.dart';
part 'folder_model.g.dart';

@immutable
@JsonSerializable(explicitToJson: true, includeIfNull: false)
class FolderModel {

  @JsonKey(name: 'id')
  late final String id;
  @JsonKey(name: 'userId')
  final String userId;
  @JsonKey(name: 'name')
  final String name;
  @JsonKey(name: 'imageUrl')
  final String imageUrl;
  @JsonKey(name: 'note')
  final String note;

  FolderModel.id(this.userId, this.name, this.imageUrl, this.note) : id = const Uuid().v1();

  FolderModel(this.id, this.userId, this.name, this.imageUrl, this.note);

  factory FolderModel.fromJson(Map<String, dynamic> json) => _$FolderModelFromJson(json);
  Map<String, dynamic> toJson() => _$FolderModelToJson(this);

  void onClickCard(FolderModel folder, String userCredential, BuildContext context, bool isEditable) {
    Navigator.of(context).push(
      MaterialPageRoute(
        builder: (_) => GridViewList(
          title: folder.name,
          firebaseCollectionName: 'items',
          userCredential: userCredential,
          folder: folder,
          onClickAdd: onClickAdd,
          isEditable: isEditable,
        ),
      ),
    );
  }

  void onClickAdd(BuildContext context, FolderModel? folder, String userCredential) {
    Navigator.of(context).push(
      MaterialPageRoute(
        builder: (_) {
          return CardDetails(userCredential: userCredential,
            folderModel: folder, cardName: 'Item',);
        },
      ),
    );
  }

  void onClickDelete() {
    FolderModelFirebase.deleteFolder(this);
  }
}
